import pandas as pd

def pandas_explorer(data_frame):
    return_dict = dict()
    
    describe = data_frame.describe(include = "all")
    number_of_rows = df.shape[0]
    number_of_column = df.shape[1]
    corr = df.corr()
    
    return_dict['describe'] = describe
    return_dict['number_of_rows'] = number_of_rows
    return_dict['number_of_column'] = number_of_column
    return_dict['corr'] = corr 
    
    return return_dict




from setuptools import setup, find_packages
  
setup(
    name='fast_explorer',
    version='0.1.1',
    description='package to explore pandas data easily',
    long_description="package to explore pandas data easily",
    long_description_content_type="text/markdown",
    keywords=['pandas', 'data', 'anaysis'],
    url='',
    author='Priyal Bankar',
    author_email='bankarpriyal08@gmail.com',
    license='MIT',
    packages=find_packages(),
    install_requires=['pandas'],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Scientific/Engineering :: Mathematics',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        'Programming Language :: Python :: 3.7',
    ],
    package_data={
        # If any package contains *.txt files, include them:
        #         '': ['*.sav'],
        # And include any *.dat files found in the 'data' subdirectory
        # of the 'mypkg' package, also:
        #'customer_models': ['model_objs/*.sav'],
    })